

# README

# Title of Dataset: 
“Behavioral differences underlie toxicity and predation variation in blooms of Prymnesium parvum.” 
---

This dataset includes all raw data used in the analyses reported in the above manuscript by Driscoll et al.


## Description of the Data and file structure

All data files are available in CSV format, and each should stand alone without reference to other files. Each file includes all data required for the corresponding analyses reported in the main text and associated supplementary materials:

| Data file       | Figure | Supp. material|
| --------------- | ------ | --- |
|cryptophyte_bioassay_all_data.csv|Figure 1B|Figure S1; Table S1|
|cell_sizes.csv|Figure 1C|Table S2|   
|growth_data.csv|Figure 2|Figure S2; Table S3|
|crypto_insert_data.csv|Figure 3|Table S4| |
| speed_data.csv|Figure 5|Table S5|          |
| chemotaxis_data.csv|Figure 6|Table S6     |



# Table of Contents
* cryptophyte_bioassay_all_data.csv
* cell_sizes.csv
* growth_data.csv
* crypto_insert_data.csv
* speed_data.csv
* chemotaxis_data.csv

# File/Folder details

## Details for: cryptophyte_bioassay_all_data.csv


* Description: A comma-delimited file with all fluorescence measurements (see below) included in the cryptophyte bioassay used to compare toxicity across diverse *P. parvum* strains.
* Format(s): .csv
* Dimensions: 81 rows x 12 columns
* Variables:
    * Strain: Identifies *P. parvum* source strain.
    * Rep: Replicate number.
    * N(Pp): Approximate  *P. parvum* cell density (cells / mL)
    * PE[t1]: Log-transformed fluorescence of whole-well phycoerythrin (PE; Excitation: 488nm, Emission: 590nm) measured shortly after cryptophytes were mixed with *P. parvum* cells (~30m).
    * PE(Neg)[t1]:  Log-transformed PE fluorescence of negative controls (cryptophytes alone).
    * PE(Pos)[t1]: Log-transformed PE fluorescence of positive controls (cryptophytes completely lysed by highly toxic *P. parvum* lysate).
    * %dead[t1]  
    * PE[t2]: Log-transformed fluorescence of whole-well PE measured 2h after cryptophytes were mixed with *P. parvum* cells, immediately prior to removing suspended cell fractions.
    * ChlA[t2]: Log-transformed fluorescence of whole-well Chlorophyll A (ChlA; Excitation: 488nm, Emission: 680nm) measured 2h after cryptophytes were mixed with *P. parvum* cells, immediately prior to removing suspended cell fractions.
    * PE(Susp)[t3]: Log-transformed PE fluorescence of suspended cell fractions, approximately 2.5h hours after cryptophytes were mixed with *P. parvum* cells.
    * ChlA(Susp)[t3]: Log-transformed ChlA fluorescence of suspended cell fractions, approximately 2.5h hours after cryptophytes were mixed with *P. parvum* cells.
    * Susp[t3]QC: Several readings of suspended cell fraction flourescence were excluded on the basis of obvious carry-over of (high PE) settled cell debris during handling. Note that these excluded values did not affect the main toxicity estimates reported in Figure 1, which were based on whole-well PE fluorescence.


* Missing data codes: See below
* Other encoding details: 
    * The variable Susp[t3]QC indicates rows for which PE(Susp)[t3] values *only* were excluded; earlier measurements (whole well PE and ChlA fluorescence measures at t1 and t2) were not affected, and so were included in all analyses.

## Details for: cell_sizes.csv

* Description: A file containing individual cell size data used to compare cell sizes among strains. 
* Format(s): .csv
* Dimensions: 266 rows x 6 columns
* Variables:
    * Strain: Identifies source strain for each cell.
    * Image: Specifies source image for each cell, from first (1) to last (15 or 16) acquired.
    * Cell_ID: Identifies each individual cell measured.
    * Major[um]: Major cell axis length.
    * Minor[um]: Minor cell axis length.
    * Vol[um^3]: Cell volume estimated using the formula for ellipsoids: V=(4/3)π * Major *  Minor^2 
* Missing data codes:N/A
* Other encoding details: The raw Major and Minor axis data was exported from ImageJ2, and acquired using the native ImageJ "Analyze Particles" function.
    * Rueden, C. T., Schindelin, J., Hiner, M. C., DeZonia, B. E., Walter, A. E., Arena, E. T., & Eliceiri, K. W. (2017). ImageJ2: ImageJ for the next generation of scientific image data. BMC bioinformatics, 18(1), 1-26.

## Details for: growth_data.csv

* Description: A comma-delimited file with the raw cell density data used to estimate nutritional preference across diverse strains of *P. parvum*.
* Format(s): .csv
* Dimensions: 631 rows x 5 columns
* Variables:
    * Strain: Identifies *P. parvum* source strain.
    * Rep: Biological replicate number.
    * Time[days]: Time from the beginning of the experiment (Time = 0) of each count.
    * Treatment: Indicates source of phosphorous supplied to *P. parvum* cultures, either "Prey" (live green algae) or "PO4" (standard, dissolved inorganic phosphate).
    * N(Pp): Approximate  *P. parvum* cell density estimated by manual cell counts (cells / mL) 
* Missing data codes: N/A
* Other encoding details: N/A


## Details for: crypto_insert_data.csv

* Description: A comma-delimited file with the raw cell density data used to estimate toxicity of different *P. parvum* culture fractions.
* Format(s): .csv
* Dimensions: 12 rows x 4 columns
* Variables:
    * Treatment: Indicates fraction of highly toxic *P. parvum* 13A5 culture added to the permeable insert, "Lysate" = mechanically lysed cells, "Filtrate" = cell-free culture medium, "Cells" = live cells, washed in filtered seawater (FSW), "Neg" = negative control, only FSW added to the membrane.
    * Rep: Replicate number.
    * N(dead): Approximate density of dead cryptophytes estimated by manual cell counts (cells / mL) 
    * N(live): Approximate density of live (motile, membranes undisrupted) cryptophytes estimated by manual cell counts (cells / mL) 
* Missing data codes: N/A
* Other encoding details: N/A


## Details for: speed_data.csv

* Description: A comma-delimited file with the motility data extracted from 10s videos using TrackMate2 (a plugin available for ImageJ2) in order to compare behaviors of diverse strains of *P. parvum*.
* Format(s): .csv
* Dimensions: 2378 rows x 8 columns
* Variables:
    * Strain: Identifies *P. parvum* source strain.
    * Rep: Replicate number.
    * Video: Video (file) number (1-5).
    * Track ID: Unique ID number for each track measured.
    * Straight Line Speed: Total track displacement (start to finish) / total track duration
    * Mean velocity: Average of instantaneous velocity estimates between subsequent frames.
    * Duration: Total number of frames that a particular cell was tracked (frame rate = 30fps).
    * Cluster: Automated clustering assigned all tracks into one of two clusters, 1 = non-motile (or very low motility), 2 = motile. (See paper for details on clustering.)
    
* Missing data codes: N/A
* Other encoding details: All velocity data was exported from the TrackMate plugin for ImageJ2.
    * Rueden, C. T., Schindelin, J., Hiner, M. C., DeZonia, B. E., Walter, A. E., Arena, E. T., & Eliceiri, K. W. (2017). ImageJ2: ImageJ for the next generation of scientific image data. BMC bioinformatics, 18(1), 1-26.
    * Tinevez, J. Y., Perry, N., Schindelin, J., Hoopes, G. M., Reynolds, G. D., Laplantine, E., ... & Eliceiri, K. W. (2017). TrackMate: An open and extensible platform for single-particle tracking. Methods, 115, 80-90.


## Details for: chemotaxis_data.csv

* Description: A comma-delimited file with the raw cell density data used to estimate nutritional preference across diverse strains of *P. parvum*.
* Format(s): .csv
* Dimensions: 41 rows x 4 columns
* Variables:
    * Strain: Identifies *P. parvum* source strain.
    * Rep: Biological replicate number.
    * N(Pp,Prey): Approximate *P. parvum* cell density in the prey lysate attractant estimated by manual cell counts (cells / mL).
    * N(Pp,PO4): Approximate  *P. parvum* cell density in the inorganic phosphate attractant estimated by manual cell counts (cells / mL). 
* Missing data codes: N/A
* Other encoding details: N/A


## Sharing/access Information

Links to other publicly accessible locations of the data: N/A